/* ----------------------------------------------------------------------------
  f2cad: Convert Fortran to C++ AD Types: Copyright (C) 2005-10 Bradley M. Bell
  Authors:  Bradley M. Bell    bradbell at washington dot edu
  License:  GNU Public License Version 2 or higher
-----------------------------------------------------------------------------*/

/*
$begin idamax$$
$spell
	hpp
	idamax
	bool
	doublereal
	Blas
	dx
	incx
$$

$section  idamax$$

$index blas, idamax$$
$index idamax, blas$$

$head Prototype$$
$include p.omh/idamax.p.omh$$


$children%
	omh/idamax.f.omh
%$$
$head Fortran Source$$
$cref idamax.f$$

$head Description$$
This example uses the routine 
$codei%idamax.f%$$ to
determine the index corresponding to the maximum element in the vector
$latex \[
\left( \begin{array}{cccc}
	1 & 2 & 5 & 4
\end{array} \right)
\] $$
The maximum element is 5 and its index (in Fortran notation) is 3. 

$codep */

# include <f2cad/idamax.hpp>

test_result idamax(void)
{	bool ok = true;

	// dx is a vector of length 4
	double     data[] = {1, 2, 5, 4};
	doublereal dx[4];
	integer i;
	for(i = 0; i < 4; i++)
		dx[i] = data[i];

	// other arguments to idamax
	integer n    = 4;
	integer incx = 1;

	// check return value
	ok &= ( 3 == f2cad::idamax_(&n, dx, &incx) );

	if( ok )
		return test_pass;
	return test_fail;
}
/* $$
$end
*/
